@@ -12,7 +12,7 @@ package Algorithm::BitVector;
 # arrays.
 # -----------------------------------------------------------------------------------
 
-use 5.10.0;
+#use 5.10.0;
 use strict;
 use warnings;
 use Carp;
@@ -21,7 +21,7 @@ use Math::BigInt;
 use Math::Random;
 use Fcntl 'SEEK_CUR';
 
-our $VERSION = '1.21';
+our $VERSION = '1.22';
 
 use overload  '+'        =>    '_join',
               '""'       =>    '_str',
@@ -816,9 +816,9 @@ sub  gcd {
     return Algorithm::BitVector->new( intVal => $a );
 }
 
-##  Calculates the multiplicative inverse of a bitvector modulo the bitvector            
-##  that is supplied as the argument. Code based on the Extended Euclid's                  
-##  Algorithm.                                                                             
+##  Calculates the multiplicative inverse of the bitvector on which the method is
+##  invoked modulo the bitvector that is supplied as the argument. Code based on
+##  Extended Euclid's Algorithm.
 sub multiplicative_inverse {
     my $self = int( shift );
     my $modulus = int( shift );
@@ -839,10 +839,9 @@ sub multiplicative_inverse {
     }
 }
 
-##  For a one-bit in-place left non-circular shift.  Note that bitvector size              
-##  does not change.  The leftmost bit that moves past the first element of the            
-##  bitvector is discarded and rightmost bit of the returned vector is set to              
-##  zero.                                                                                  
+##  For a one-bit in-place left non-circular shift.  Note that the bitvector size
+##  does not change.  The leftmost bit that moves past the first element of the
+##  bitvector is discarded and rightmost bit of the returned vector is set to zero.
 sub _shift_left_by_one {
     my $self = shift;
     my $size = @{$self->{_vector}};
@@ -869,10 +868,10 @@ sub shift_left {
     return $self;
 }
 
-##  For a one-bit in-place right non-circular shift.  Note that bitvector size             
-##  does not change.  The rightmost bit that moves past the last element of the            
-##  bitvector is discarded and leftmost bit of the returned vector is set to               
-##  zero.                                                                                  
+##  For a one-bit in-place right non-circular shift.  Note that bitvector size does
+##  not change.  The rightmost bit that moves past the last element of the bitvector
+##  on the right is discarded and the leftmost bit of the returned vector is set to
+##  zero.
 sub _shift_right_by_one {
     my $self = shift;
     my $size = @{$self->{_vector}};
@@ -888,9 +887,9 @@ sub _shift_right_by_one {
     $self->set_bit(0,0);
 }
 
-##  For an in-place right non-circular shift by n bit positions.  The n bits that move
-##  past the last element of the bitvector are discarded and leftmost new n bit positions
-##  filled with zeros.
+##  For an in-place right non-circular shift by n bit positions.  The n bits that
+##  move past the last element of the bitvector on the right are discarded and
+##  leftmost new n bit positions filled with zeros.
 sub shift_right {
     my $self = shift;
     my $n = shift;
@@ -901,11 +900,11 @@ sub shift_right {
 }
 
 ##  In the set of polynomials defined over GF(2), multiplies the bitvector on which
-##  the method is invoked with the bitvector b.  Returns the product bitvector.  Note
-##  that this method does NOT carry out straight polynomial multiplication as opposed
-##  to modulo polynomial multiplication. As a result, the highest power of the result
-##  polynomial will ALWAYS be greater than the highest powers of the argument
-##  polynomials for non-trivial multiplications.
+##  the method is invoked with the argument bitvector.  Returns the product
+##  bitvector.  Note that this method carries out straight polynomial multiplication
+##  as opposed to modulo polynomial multiplication. As a result, the highest power of
+##  the result polynomial will ALWAYS be greater than the highest powers of the
+##  argument polynomials for non-trivial multiplications.
 sub gf_multiply {
     my $self = shift;
     my $b = shift;
@@ -990,7 +989,6 @@ sub  gf_MI {
     my $y = Algorithm::BitVector->new( intVal => 1, size => $mod->{size} );
     my $y_old = Algorithm::BitVector->new( size => $mod->{size} );
     my ($quotient, $remainder);
-
     while (int($mod)) {
         ($quotient, $remainder) = $num->gf_divide_by_modulus($mod, $n);
         ($num, $mod) = ($mod, $remainder);
@@ -1048,6 +1046,7 @@ sub test_for_primality {
         "small integers --- integers that are relatively small in relation to " .
         "the largest integer that can fit Perl's 4-byte int representation:$!"
         if $p > 0x7f_ff_ff_ff;
+    return "is NOT a prime" if $p == 1;
     my @probes = (2,3,5,7,11,13,17);
     foreach my $a (@probes) {
         return "is a prime" if $a == $p;
@@ -1186,6 +1185,9 @@ bit arrays and for logical and arithmetic operations on such arrays.
 
 =head1 CHANGES
 
+Version 1.22 removes the Perl version constraints from the module and the
+C<Makefile.PL> files and the C<PREREQ_PM> constraints from the C<Makefile.PL> file.
+
 Version 1.21 fixes a bug in the code for the Miller-Rabin primality test function
 C<test_for_primality()>.  This version also places a hard limit on the size of the
 integers that are allowed to be tested for primality.
@@ -2084,7 +2086,7 @@ otherwise the bit pattern `00001010' ('\n') in your bitstring will be written ou
 
 =back
 
-=head1 REQUIRED
+=head1 IMPORTS
 
 This module imports the following modules:
 
@@ -2118,10 +2120,10 @@ the string 'BitVector' in the subject line.
 Download the archive from CPAN in any directory of your choice.  Unpack the archive
 with a command that on a Linux machine would look like:
 
-    tar zxvf Algorithm-BitVector-1.21.tar.gz
+    tar zxvf Algorithm-BitVector-1.22.tar.gz
 
 This will create an installation directory for you whose name will be
-C<Algorithm-BitVector-1.21>.  Enter this directory and execute the following commands
+C<Algorithm-BitVector-1.22>.  Enter this directory and execute the following commands
 for a standard install of the module if you have root privileges:
 
     perl Makefile.PL
@@ -2153,8 +2155,11 @@ If I used bash, I'd need to declare:
 =head1 THANKS
 
 The bug in the primality test function, whose fix resulted in Version 1.21, was
-reported by Dana Jacobsen in a bug report filed at C<rt.cpan.org>.  Thanks
-Dana!
+reported by Dana Jacobsen in a bug report filed at C<rt.cpan.org>.  Thanks Dana!
+
+The Perl and the C<PREREQ_PM> constraints were removed in Version 1.22 on Slaven
+Rezic's recommendation.  He says the module runs fine with Perl 5.8.9.  Thanks
+Slaven!
 
 =head1 AUTHOR
 
